@@ -79,8 +79,8 @@ sub update_or_insert {
                 : $self->insert($param, %opt, %{$statement_opt->{insert} || {}});
 }
 
-
 sub execute {
+    warn "DBIx::Custom::Model execute method is DEPRECATED!";
     my $self = shift;
     return $self->dbi->execute(
         shift,
@@ -207,7 +207,7 @@ Table name, this is passed to C<select> method.
     
 Database data type, this is used as type optioon of C<insert>, 
 C<update>, C<update_all>, C<delete>, C<delete_all>,
-C<select>, and C<execute> method
+and C<select> method
 
 =head2 C<updated_at EXPERIMENTAL>
 
@@ -244,13 +244,6 @@ you don't have to specify options if you set attribute in model.
 Same as C<delete_all> of L<DBIx::Custom> except that
 you don't have to specify options if you set attribute in model.
 
-=head2 C<execute>
-
-    $model->execute(...);
-
-Same as C<execute> of L<DBIx::Custom> except that
-you don't have to specify options if you set attribute in model.
-
 =head2 C<insert>
 
     $model->insert(...);
